@@ -29,6 +29,8 @@ most of its code.
 
 =cut
 
+# use Sepia '_apropos_re';
+require Sepia;
 BEGIN { *_apropos_re = *Sepia::_apropos_re; }
 $VERSION = '0.65';
 
@@ -38,8 +40,8 @@ use Cwd 'abs_path';
 use B qw(peekop class comppadlist main_start svref_2object walksymtable
          OPpLVAL_INTRO SVf_POK OPpOUR_INTRO OPf_MOD OPpDEREF_HV OPpDEREF_AV
 	 cstring);
-# use Sepia '_apropos_re';
-require Sepia;
+# stupid warnings...
+no warnings 'uninitialized';
 
 =head2 Variables
 
@@ -114,6 +116,8 @@ my %code = (intro => "i", used => "",
 	    formdef => "f", meth => "->");
 
 
+=head2 Functions
+
 =item C<guess_module_file($pack, $ofile)>
 
 XXX: it turns out that rooting around trying to figure out the file
@@ -130,6 +134,7 @@ sub guess_module_file {
     return undef if $ofile =~ /Exporter\.pm$/;
     # Try for standard translation in %INC:
     (my $fn = $pack) =~ s/::/\//g;
+    return unless $fn;          # stupid warnings...
     if (exists $INC{"$fn.pm"}) {
 	return $INC{"$fn.pm"};
     }
@@ -201,7 +206,6 @@ sub process {
 	my ($spack, $sname) = split_name($subname);
 
 	$call{$name}{$pack}{$subname} = 1;
-
 	$callby{$sname}{$spack}{"$pack\::$name"} = 1;
     } elsif ($type eq 's' || $subname eq '(definitions)') {
 	# definition
@@ -255,6 +259,10 @@ sub load_pad {
 	    next unless class($valsv) eq "GV";
 	    # these pad GVs don't have corresponding names, so same @pad
 	    # array can be used without collisions
+
+            # XXX: for some reason, on 5.10 $valsv->STASH can be a
+            # B::SPECIAL, which doesn't have a name.
+            next if ref $valsv->STASH eq 'B::SPECIAL';
 	    $pad[$ix] = [$valsv->STASH->NAME, "*", $valsv->NAME];
 	}
     }
@@ -489,10 +497,6 @@ sub xref_definitions {
     walksymtable(\%{"main::"}, "xref", sub { !xref_exclude($_[0]) });
 }
 
-=head2 Functions
-
-=over
-
 =item C<rebuild()>
 
 Rebuild the Xref database.
@@ -672,10 +676,13 @@ List the modules defined in file C<$file>.
 
 sub file_modules {
     my $file = shift;
-    eval "use Module::Include;" and do {
-        my $mod = Module::Include->new_from_file(abs_path($file));
-        return ($mod && $mod->packages_inside) || undef;
-    };
+    eval {
+        require Module::Info;
+        my $mod = Module::Info->new_from_file(abs_path($file));
+        if ( $mod ) {
+            return $mod->packages_inside();
+        }
+    }
 }
 
 =item C<var_apropos($expr)>
